<?php
/**
 * @version 	2.1 Date: 25 Feb 2021
 * @date        25 Feb 2021
 * @developer 	SafetyBis Ltd 
 * @copyright 	(c) 2013-2020 www.safetybis.com , www.siteguarding.com
 * @contacts 	support@safetybis.com, support@siteguarding.com
 * @license		GNU/GPL, http://www.gnu.org/licenses/gpl-3.0.html
 */
 
defined('_JEXEC') or die('Restricted access');

jimport('joomla.plugin.plugin');

class plgSystemjAdminProtection extends JPlugin
{
    public $notify_time = 0;
    public $htaccess_contents = '';
    public $htaccess_exist_flag = false;
    public $ip_addr = '';
    public $custom_params = array();


	function __construct(& $subject, $config)
	{
		parent::__construct($subject, $config);
        $this->GetCustomParams();
	}
	
	function onAfterDispatch()
	{
	    $config = JFactory::getConfig();
		$mainframe 	= JFactory::getApplication();
		$user 		= JFactory::getUser();
		$session	= JFactory::getSession();
        
        // Load langs
        $language =& JFactory::getLanguage();
        $extension = 'plg_system_jadminprotection';
        $language_tag = $language->getTag();
        $language->load($extension, JPATH_ADMINISTRATOR, null/*$language_tag*/, true);

        global $_SERVER;
        $this->ip_addr = $_SERVER['REMOTE_ADDR']; 
        
        // Execute when plugin saved
        $product_type = $this->CheckRegCode();  // true - paid, false - free
        if (is_null($product_type)) return;  
        
        // When in admin area
        if ($mainframe->isAdmin())
        {
            // Check settings
            $this->CheckSettings();
            // Update .htaccess
            $this->Update_htaccess();
            // Update CheckSum for Notify Developer
            $this->NotifyDeveloper();
            // Update Advert
            $this->NotifyDate();

        }
        


		// Backend Admin
		if (!$mainframe->isAdmin() || 
            !$user->get('guest') || 
            $session->get('jAdminProtection')) return;
        
        
        // Start
        
        $allowed_ip_list = trim($this->params->get('allowed_ip_list'));
        if ($allowed_ip_list != '')
        {
            $allowed_ip_list = explode("\n", $allowed_ip_list);
            
            // Check for version limitations
            if (count($allowed_ip_list) > 5 && $this->CheckRegCode() === false)
            {
                // Limit reached, Send alert to admin
                $this->NotifyAdmin( JText::_('JAP_PLG_ALLOWED_IP_LIMIT_REACHED') );
                return;
            }
            
            if (count($allowed_ip_list))
            {
                foreach ($allowed_ip_list as $v)
                {
                    if (trim($v) == $this->ip_addr) 
                    {
                        // Allow access
                        $session->set('jAdminProtection', true);
                        // Send alert to admin
                        if ($this->params->get('notification_type') == 1 || $this->params->get('notification_type') == 3)
                        {
                            $this->NotifyAdmin( JText::_('JAP_PLG_USER_GET_ACCESS_ALLOWED_IP') );
                        }
                        return;
                    }
                }
            }
        }
        
		
        $mode = $this->params->get('mode'); 
        if ($mode == 0) // Secure Uniq Link
        {
            $link_password = trim( $this->params->get('link_password') );
            if ($link_password == '') 
            {
                // Empty password, send alert to admin
                $this->NotifyAdmin( JText::_('JAP_PLG_EMPTY_PASSWORD') );
                return; 
            }
            
            // Check for version limitations
            if (strlen($link_password) > 8 && $this->CheckRegCode() === false)
            {
                // Limit reached, Send alert to admin
                $this->NotifyAdmin( JText::_('JAP_PLG_LIMIT_PASSWORD') );
                return;
            }
            
            
			if (!isset($_GET[$link_password]))
            {
                // Wrong password
                $this->BanIP($this->ip_addr);
                // Send alert to admin
                if ($this->params->get('notification_type') == 2 || $this->params->get('notification_type') == 3)
                {
                    $this->NotifyAdmin( JText::_('JAP_PLG_USER_FAIL_ACCESS') );
                }
                // Redirect to home
                $mainframe->redirect(JURI::root());
                return;
            }
            else {
                // Password ok
                $session->set('jAdminProtection', true);
                $this->unBanIP($this->ip_addr);
                // Send alert to admin
                if ($this->params->get('notification_type') == 1 || $this->params->get('notification_type') == 3)
                {
                    $this->NotifyAdmin( JText::_('JAP_PLG_USER_GET_ACCESS') );
                }
                return;
            }
        }
        
        
        if ($mode == 1) // Extra Password Form
        {
            global $_SERVER;
            
            $form_username = trim( $this->params->get('form_username') );
            $form_password = trim( $this->params->get('form_password') );
            
            if ($form_username == '' || $form_password == '') 
            {
                // Empty form username or password, send alert to admin
                $this->NotifyAdmin( JText::_('JAP_PLG_EMPTY_FORMACCESS') );
                return; 
            }

			if (substr(php_sapi_name(), 0, 3) == 'cgi')
			{
                list($_SERVER['PHP_AUTH_USER'], $_SERVER['PHP_AUTH_PW']) = explode(':' , base64_decode(substr($_SERVER['REMOTE_USER'], 6)));
			}

            if (!$_SERVER['PHP_AUTH_USER']) 
            {
                header('WWW-Authenticate: Basic realm="'.$config->get('sitename').'"');
                header('HTTP/1.0 401 Unauthorized');
                echo 'You cannot see this page, sorry.';
                exit;
            }
            
            
            // PHP works as Apache
			if ($_SERVER['PHP_AUTH_USER'] == $form_username && $_SERVER['PHP_AUTH_PW'] == $form_password)
            {
                // Password ok
                $session->set('jAdminProtection', true);
                $this->unBanIP($this->ip_addr);
                // Send alert to admin
                if ($this->params->get('notification_type') == 1 || $this->params->get('notification_type') == 3)
                {
                    $this->NotifyAdmin( JText::_('JAP_PLG_USER_GET_ACCESS') );
                }
                return;
            }
            else {
                // Wrong password
                $this->BanIP($this->ip_addr);
                // Send alert to admin
                if ($this->params->get('notification_type') == 2 || $this->params->get('notification_type') == 3)
                {
                    $this->NotifyAdmin( JText::_('JAP_PLG_USER_FAIL_FORMACCESS') );
                }
                // Redirect to home
                //$mainframe->redirect(JURI::root());
				header('WWW-Authenticate: Basic realm="'.$config->get('sitename').'"');
				header('HTTP/1.0 401 Unauthorized');
				die();
            }
            


        }
	}
    
    
    function NotifyAdmin($message, $is_advert = false)
    {
        $domain = strtolower( str_replace("/administrator", "", JURI::base()) );
        
		$config = JFactory::getConfig();
		$mailfrom = $config->get( 'config.mailfrom' );
		$fromname = $config->get( 'config.fromname' );
        $subject = $this->params->get('notification_email_subject');
        $subject = str_replace("{URL}", $domain, $subject);
        $mailto = trim($this->params->get('notification_email'));
        if ($mailto == 'your@email.com' || $mailto == '') $mailto = $mailfrom;
        
        if ($is_advert) 
        {
            $mailfrom = 'support@siteguarding.com';
            $fromname = 'SiteGuarding.com';
            $subject = 'Security Tip';
        }
        
        $body_message = '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>SiteGuarding - Professional Web Security Services!</title>
</head>
<body bgcolor="#ECECEC">
<table cellpadding="0" cellspacing="0" width="100%" align="center" border="0">
  <tr>
    <td width="100%" align="center" bgcolor="#ECECEC" style="padding: 5px 30px 20px 30px;">
      <table width="750" border="0" align="center" cellpadding="0" cellspacing="0" bgcolor="#fff" style="background-color: #fff;">
        <tr>
          <td width="750" bgcolor="#fff"><table width="750" border="0" cellspacing="0" cellpadding="0" bgcolor="#fff" style="background-color: #fff;">
            <tr>
              <td width="350" height="60" bgcolor="#fff" style="padding: 5px; background-color: #fff;"><a href="http://www.siteguarding.com/" target="_blank"><img src="http://securapp2.safetybis.com/templates/security/images/logo_siteguarding.gif" alt="SiteGuarding - Protect your website from unathorized access, malware and other threat" height="60" border="0" style="display:block" /></a></td>
              <td width="400" height="60" align="right" bgcolor="#fff" style="background-color: #fff;">
              <table border="0" cellspacing="0" cellpadding="0" bgcolor="#fff" style="background-color: #fff;">
                <tr>
                  <td style="font-family:Arial, Helvetica, sans-serif; font-size:11px;"><a href="http://www.siteguarding.com/en/login" target="_blank" style="color:#656565; text-decoration: none;">Login</a></td>
                  <td width="15"></td>
                  <td width="1" bgcolor="#656565"></td>
                  <td width="15"></td>
                  <td style="font-family:Arial, Helvetica, sans-serif; font-size:11px;"><a href="http://www.siteguarding.com/en/prices" target="_blank" style="color:#656565; text-decoration: none;">Services</a></td>
                  <td width="15"></td>
                  <td width="1" bgcolor="#656565"></td>
                  <td width="15"></td>
                  <td style="font-family:Arial, Helvetica, sans-serif; font-size:11px;"><a href="http://www.siteguarding.com/en/what-to-do-if-your-website-has-been-hacked" target="_blank" style="color:#656565; text-decoration: none;">Security Tips</a></td>            
                  <td width="15"></td>
                  <td width="1" bgcolor="#656565"></td>
                  <td width="15"></td>
                  <td style="font-family:Arial, Helvetica, sans-serif;  font-size:11px;"><a href="http://www.siteguarding.com/en/contacts" target="_blank" style="color:#656565; text-decoration: none;">Contacts</a></td>
                  <td width="30"></td>
                </tr>
              </table>
              </td>
            </tr>
          </table></td>
        </tr>

        <tr>
          <td width="750" height="2" bgcolor="#D9D9D9"></td>
        </tr>
        <tr>
          <td width="750" bgcolor="#fff" ><table width="750" border="0" cellspacing="0" cellpadding="0" bgcolor="#fff" style="background-color:#fff;">
            <tr>
              <td width="750" height="30"></td>
            </tr>
            <tr>
              <td width="750">
                <table width="750" border="0" cellspacing="0" cellpadding="0" bgcolor="#fff" style="background-color:#fff;">
                <tr>
                  <td width="30"></td>
                  <td width="690" bgcolor="#fff" align="left" style="background-color:#fff; font-family:Arial, Helvetica, sans-serif; color:#000000; font-size:12px;">
                    <br />
                    {MESSAGE_CONTENT}
                  </td>
                  <td width="30"></td>
                </tr>
              </table></td>
            </tr>
            <tr>
              <td width="750" height="15"></td>
            </tr>
            <tr>
              <td width="750" height="15"></td>
            </tr>
            <tr>
              <td width="750"><table width="750" border="0" cellspacing="0" cellpadding="0">
                <tr>
                  <td width="30"></td>
                  <td width="690" align="left" style="font-family:Arial, Helvetica, sans-serif; color:#000000; font-size:12px;"><strong>How can we help?</strong><br />
                    If you have any questions please dont hesitate to contact us. Our support team will be happy to answer your questions 24 hours a day, 7 days a week. You can contact us at <a href="mailto:support@siteguarding.com" style="color:#2C8D2C;"><strong>support@siteguarding.com</strong></a>.<br />
                    <br />
                    Thanks again for choosing SiteGuarding as your security partner!<br />
                    <br />
                    <span style="color:#2C8D2C;"><strong>SiteGuarding Team</strong></span><br />
                    <span style="font-family:Arial, Helvetica, sans-serif; color:#000; font-size:11px;"><strong>We will help you to protect your website from unauthorized access, malware and other threats.</strong></span></td>
                  <td width="30"></td>
                </tr>
              </table></td>
            </tr>
            <tr>
              <td width="750" height="30"></td>
            </tr>
          </table></td>
        </tr>
        <tr>
          <td width="750" height="2" bgcolor="#D9D9D9"></td>
        </tr>
      </table>
      <table width="750" border="0" cellspacing="0" cellpadding="0">
        <tr>
          <td width="750" height="10"></td>
        </tr>
        <tr>
          <td width="750" align="center"><table border="0" cellspacing="0" cellpadding="0">
            <tr>
              <td style="font-family:Arial, Helvetica, sans-serif; color:#ffffff; font-size:10px;"><a href="http://www.siteguarding.com/en/website-daily-scanning-and-analysis" target="_blank" style="color:#656565; text-decoration: none;">Website Daily Scanning</a></td>
              <td width="15"></td>
              <td width="1" bgcolor="#656565"></td>
              <td width="15"></td>
              <td style="font-family:Arial, Helvetica, sans-serif; color:#ffffff; font-size:10px;"><a href="http://www.siteguarding.com/en/malware-backdoor-removal" target="_blank" style="color:#656565; text-decoration: none;">Malware & Backdoor Removal</a></td>
              <td width="15"></td>
              <td width="1" bgcolor="#656565"></td>
              <td width="15"></td>
              <td style="font-family:Arial, Helvetica, sans-serif; color:#ffffff; font-size:10px;"><a href="http://www.siteguarding.com/en/update-scripts-on-your-website" target="_blank" style="color:#656565; text-decoration: none;">Security Analyze & Update</a></td>
              <td width="15"></td>
              <td width="1" bgcolor="#656565"></td>
              <td width="15"></td>
              <td style="font-family:Arial, Helvetica, sans-serif; color:#ffffff; font-size:10px;"><a href="http://www.siteguarding.com/en/website-development-and-promotion" target="_blank" style="color:#656565; text-decoration: none;">Website Development</a></td>
            </tr>
          </table></td>
        </tr>

        <tr>
          <td width="750" height="10"></td>
        </tr>
        <tr>
          <td width="750" align="center" style="font-family: Arial,Helvetica,sans-serif; font-size: 10px; color: #656565;">Add <a href="mailto:support@siteguarding.com" style="color:#656565">support@siteguarding.com</a> to the trusted senders list.</td>
        </tr>
      </table>
    </td>
  </tr>
</table>
</body>
</html>';
        
        $txt .= $message;
        
        global $_SERVER;
        $a = array("{IP}", "{DATE}", "{LINK_PASSWORD}", "{FORM_USERNAME}", "{FORM_PASSWORD}", "{DOMAIN_URL}");
        $b = array($_SERVER['REMOTE_ADDR'], date("Y-m-d H:i:s"), $_SERVER['REQUEST_URI'], $_SERVER['PHP_AUTH_USER'], $_SERVER['PHP_AUTH_PW'], $domain);
        
        $txt = str_replace($a, $b, $txt); 
        
        $body_message = str_replace("{MESSAGE_CONTENT}", $txt, $body_message);
        
        $mailer = JFactory::getMailer();
        $sender = array($mailfrom,$fromname);
        $mailer->setSender($sender);
        $mailto_array = explode(",", $mailto);
        if (count($mailto_array) > 1)
        {
            foreach ($mailto_array as $k => $v)
            {
                $mailto_array[$k] = trim($v);
            }
            
            // Check paid version
            if ($this->CheckRegCode() === true) $mailto = $mailto_array;
            else $mailto = $mailto_array[0];
        }

        $mailer->addRecipient($mailto);
        $mailer->setSubject($subject);
        $mailer->isHTML(true);
        $mailer->setBody($body_message);
        $mailer->Send();
    }
    
    
    function CheckSettings()
    {
        if ($this->params->get('mode') == 0 && trim( $this->params->get('link_password') ) == '')
        {
            JError::raiseWarning( 100, JText::_('JAP_PLG_EMPTY_PASSWORD') );    
        }  
        
        if ($this->params->get('mode') == 1 && ( trim( $this->params->get('form_username') ) == '' || (trim( $this->params->get('form_password') ) == '') ) )
        {
            JError::raiseWarning( 100, JText::_('JAP_PLG_EMPTY_FORMACCESS') );    
        }   
        
        // Validate email
        $mailto = trim($this->params->get('notification_email'));
        $mailto_array = explode(",", $mailto);
        if (count($mailto_array) > 1)
        {
            // Check paid version
            if ($this->CheckRegCode() === false) JError::raiseWarning( 100, JText::_('JAP_PLG_ONLY_ONE_EMAIL') );
            foreach ($mailto_array as $k => $v)
            {
                // validate email    
                $v = trim($v);
                if (filter_var($v, FILTER_VALIDATE_EMAIL) === false) 
                {
                    JError::raiseWarning( 100, JText::_('JAP_PLG_NOT_VALID_EMAIL')." ".$v );
                }
            }
        }
        else {
            // Validate email
            if (filter_var($mailto, FILTER_VALIDATE_EMAIL) === false) 
            {
                JError::raiseWarning( 100, JText::_('JAP_PLG_NOT_VALID_EMAIL')." ".$mailto );
            }
        }
    }
    
    
    // Returns true - paid, false - free
    function CheckRegCode()
    {
        $reg_code = $this->params->get('reg_code');
        if (trim($reg_code) == '') return false;        // Free
        
        $reg_code_arr = explode("\n", $reg_code);
        $reg_code = trim($reg_code_arr[0]).trim($reg_code_arr[1])."|".trim($reg_code_arr[2]).trim($reg_code_arr[3]);
        
        $domain = parse_url(JURI::base());
        $domain = strtolower( trim($domain['host']) );
        
        $secret = strtoupper( md5( md5( md5($domain)."Version 1" )."JhdswyTGfd" ) );
        
        //$a1 = substr($secret, 0, 16);
        //$a2 = substr($secret, 16);
        
        if (strpos($reg_code, $secret) === false) 
        {
            JError::raiseWarning( 100, JText::_('JAP_PLG_WRONG_REG_CODE') );
            return null;
        }
        else return true;
    }
    
    
   
    
    function Read_htaccess_IPs()
    {
        $ip_list = array();
        $filename = JPATH_ROOT.'/administrator/.htaccess';
        $this->htaccess_exist_flag = file_exists($filename);
        if ($this->htaccess_exist_flag)
        {
            $time = time();
            
            $handle = fopen($filename, "r");
            $contents = fread($handle, filesize($filename));
            fclose($handle);
            
            $this->htaccess_contents = $contents;
            $contents = explode("\n", $contents);
            
            
            if (count($contents))
            {
                foreach ($contents as $v)
                {
                    $v = trim($v);
                    
                    if ($v[0] == '#' && $v[1] == '#' && strpos($v, "|") !== false)   // Information line
                    {
                        $v = str_replace("##", "", $v);
                        
                        $info = explode("|", $v); // 0 - ip, 1 - time, 2 - tries
                        
                        $ip = trim($info[0]);
                        $ip_list[$ip] = array(
                            "time" => intval($info[1]),
                            "attempts" => intval($info[2])
                        );
                    }
                }
            }
        }
        
        return $ip_list;
    }
    
    
    function Write_htaccess_IPs($ip_list)
    {
        // Prepare htaccess content
        $contents = '';
        
        if (substr(php_sapi_name(), 0, 3) == 'cgi' && $this->params->get('mode') == 1)
        {
            $contents .= '<IfModule mod_rewrite.c>'."\n";    
            $contents .= 'RewriteEngine on'."\n";    
            $contents .= 'RewriteRule .* - [E=REMOTE_USER:%{HTTP:Authorization},L]'."\n";    
            $contents .= '</IfModule>'."\n\n";    
        }
        
        $contents .= 'order allow,deny'."\n";
        if (count($ip_list))
        {
            $ban_ip_attempts = $this->params->get('ban_ip_attempts');
            
            foreach ($ip_list as $ip => $ip_data)
            {
                $tmp_line = "";
                if (trim($ip) != '')
                {
                    $tmp_line .= "##".$ip.'|'.$ip_data['time']."|".$ip_data['attempts']."\n";    // Information line
                    
                    if ($ip_data['attempts'] >= $ban_ip_attempts) $tmp_line .= "deny from ".$ip."\n";     // Block IP in htaccess
                }
                
                if ($tmp_line != "") $contents .= $tmp_line;
            }
        }
        $contents .= 'allow from all'."\n";
        
        
        if (strcmp($contents, $this->htaccess_contents) == 0) return;  // Dont need anything to save
        
        
        $filename = JPATH_ROOT.DS.'/administrator/.htaccess';
        $handle = fopen($filename, 'w');
        if ($handle !== false)
        {
            fwrite($handle, $contents);
            fclose($handle);
        }
        else {
            JError::raiseWarning( 100, JText::_('JAP_PLG_CANNOT_CREATE_HTACCESS') );    
        }
    }
    
    
    function Update_htaccess()
    {
        // Read .htaccess
        $ip_list = $this->Read_htaccess_IPs();
        
        // Delete const banned IPs
        if (count($ip_list))
        {
            foreach ($ip_list as $ip => $ip_data)
            {
                if ($ip_data['attempts'] == '9999') unset($ip_list[$ip]);
            }
        }
        
        
        // Check const banned list
        $banned_ip_list = trim($this->params->get('banned_ip_list'));
        if ($banned_ip_list != '')
        {
            $banned_ip_list = explode("\n", $banned_ip_list);
            
            // Check for version limitations
            if (count($banned_ip_list) > 5 && $this->CheckRegCode() === false)
            {
                // Limit reached, Send alert to admin
                JError::raiseWarning( 100, JText::_('JAP_PLG_LIMIT_BAN_IP') );
                $this->NotifyAdmin( JText::_('JAP_PLG_LIMIT_BAN_IP') );
                return;
            }
            
            if (count($banned_ip_list))
            {
                foreach ($banned_ip_list as $banned_ip)
                {
                    $banned_ip = trim($banned_ip);
                    $ip_list[$banned_ip] = array(
                        "time" => time()+5*365*24*60*60,
                        "attempts" => 9999
                    ); 
                }
            }
        }
        
        // Write .htaccess
        $this->Write_htaccess_IPs($ip_list);
    }
    
    
    function BanIP($ip)
    {
        if ($this->params->get('autoban_ip') == 0) return;  // Auto ban is disabled
        
        // Read .htaccess
        $ip_list = $this->Read_htaccess_IPs();
        
        // Ban IP
        $ban_ip_period = $this->params->get('ban_ip_period');
        
        $ip = trim($ip);
        if (isset($ip_list[$ip])) $ip_list[$ip]['attempts'] += 1;
        else $ip_list[$ip]['attempts'] = 1; 
        $ip_list[$ip]['time'] = time() + $ban_ip_period * 60;  
        
        // Check for version limitation
        if (count($ip_list) > 8 && $this->CheckRegCode() === false)
        {
            // Limit reached, Send alert to admin
            $this->NotifyAdmin( JText::_('JAP_PLG_LIMIT_AUTOBAN_IP') );
            return;
        }
        
        // Write .htaccess
        $this->Write_htaccess_IPs($ip_list);
    }
    
    
    function unBanIP($ip)
    {
        if ($this->params->get('autoban_ip') == 0) return;  // Auto ban is disabled
        
        // Read .htaccess
        $ip_list = $this->Read_htaccess_IPs();
        
        // unBan IP
        unset($ip_list[$ip]);
        
        // Write .htaccess
        $this->Write_htaccess_IPs($ip_list);
    }
    
    
    function GetCheckSum()
    {
		$config = JFactory::getConfig();
		$mail1 = $config->get( 'config.mailfrom' );
        $mail2 = trim($this->params->get('notification_email'));
        $reg = intval($this->CheckRegCode());
        $checksum = md5($mail1.$mail2.'-'.$reg);
        
        return $checksum;
    }
    
    function NotifyDate()
    {
        $notify_flag = false;
        
        $notify_date = intval($this->custom_params['notify_date']);
        
        if ($notify_date > 0)
        {
            if ($notify_date < time())
            {
                $msg = file_get_contents('http://www.siteguarding.com/_advert.php');
                $this->NotifyAdmin( $msg, true );
                $notify_flag = true;
            }

        }
        else $this->UpdateParams('notify_date', time()+30*24*60*60);
        
        if ($notify_flag) 
        {
            $this->UpdateParams('notify_date', time()+30*24*60*60);
        }
        
    }
    
    
    function NotifyDeveloper()
    {
        $notify_flag = false;
        
        $checksum = trim($this->custom_params['notify_developer']);
        if ( $checksum != '')
        {
            if ($this->GetCheckSum() != $checksum)  $notify_flag = true;   
        }
        else $this->UpdateParams('notify_developer', $this->GetCheckSum());

        if ($notify_flag)
        {
    		// Send data
            $link = 'http://www.siteguarding.com/_advert.php?action=inform&text=';
            
            $domain = parse_url(JURI::base());
            $domain = strtolower( trim($domain['host']) );
            
    		$config = JFactory::getConfig();
    		$mailfrom = $config->get( 'config.mailfrom' );
            
            $text = $domain."|".$mailfrom."|".$this->params->get('notification_email')."|Reg:".intval($this->CheckRegCode());
            
            $link .= base64_encode($text);
            $msg = file_get_contents($link);
            
            $this->UpdateParams('notify_developer', $this->GetCheckSum());
        }
        
    }
    
    
    function GetCustomParams()
    {
        $db =& JFactory::getDBO();
        $query = "SELECT custom_data
            FROM #__extensions
            WHERE element = 'jadminprotection' AND folder = 'system' LIMIT 1;";
    	$db->setQuery($query);
    	$rows = $db->loadObjectList();
		if ($db->getErrorNum())
		{
			JError::raiseWarning( 100, $db->stderr() );
			return false;
		}
        
        if (count($rows))
        {
            $params = json_decode($rows[0]->custom_data, true);
            $this->custom_params = $params;
        }
    }
    
    function UpdateParams($feild, $value)
    {
        $db =& JFactory::getDBO();
        $query = "SELECT custom_data
            FROM #__extensions
            WHERE element = 'jadminprotection' AND folder = 'system' LIMIT 1;";
    	$db->setQuery($query);
    	$rows = $db->loadObjectList();
		if ($db->getErrorNum())
		{
			JError::raiseWarning( 100, $db->stderr() );
			return false;
		}
        
        if (count($rows))
        {
            $params = json_decode($rows[0]->custom_data, true);
            $params[$feild] = $value;
            
    		$query = "UPDATE `#__extensions` SET custom_data = '".addslashes(json_encode($params))."' WHERE element = 'jadminprotection' AND folder = 'system' LIMIT 1;";
    		$db->setQuery( $query );
    		$db->query();
    		if ($db->getErrorNum())
    		{
    			JError::raiseWarning( 100, $db->stderr() );
    			return false;
    		} 
        }
    }
}


?>